@@ -306,6 +306,7 @@ class JackTrip : public QObject
     {
         mDataProtocolReceiver = DataProtocolReceiver;
     }
+    virtual int getBufferStrategy() const noexcept { return mBufferStrategy; }
 
     virtual RingBuffer* getSendRingBuffer() const { return mSendRingBuffer; }
     virtual RingBuffer* getReceiveRingBuffer() const { return mReceiveRingBuffer; }
@@ -398,6 +399,12 @@ class JackTrip : public QObject
     {
         return mReceiveRingBuffer->insertSlotNonBlocking(ptrToSlot, len, lostLen);
     }
+    virtual bool writeAudioBufferRegulator(const int8_t* ptrToSlot, int len, int seq,
+                                           int lostLen)
+    {
+        return mReceiveRingBuffer->insertSlotNonBlockingRegulator(ptrToSlot, len, seq,
+                                                                  lostLen);
+    }
     uint32_t getBufferSizeInSamples() const
     {
         return mAudioBufferSize; /*return mAudioInterface->getBufferSizeInSamples();*/
@@ -596,8 +603,8 @@ class JackTrip : public QObject
     /// \brief Starts for the CLIENT mode
     void clientStart();
     /// \brief Starts for the SERVER mode
-    /// \param timout Set the server to timeout after 2 seconds if no client connections
-    /// are received. Usefull for the multithreaded server \return 0 on success, -1 on
+    /// \param timeout Set the server to timeout after 2 seconds if no client connections
+    /// are received. Useful for the multithreaded server \return 0 on success, -1 on
     /// error
     int serverStart(bool timeout = false, int udpTimeout = gTimeOutMultiThreadedServer);
     /// \brief Stats for the Client to Ping Server
